#!/bin/sh
#
#	fhist - file history and comparison tools
#	Copyright (C) 1993, 1994 Peter Miller.
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# MANIFEST: shell script to generate the Makefile file
#
clean_files="core bin/txt2c common/lib.a"
common_files=
fcomp_files=
fhist_files=
fmerge_files=
man1_files=
test_files=
txt2c_files="common/ansi.o common/arglex.o common/cmalloc.o common/error.o"
echo
for file in $*
do
	case $file in

	fcomp/*.c)
		root=`basename $file .c`
		fcomp_files="$fcomp_files fcomp/${root}.o"
		clean_files="$clean_files fcomp/${root}.o"
		;;

	fhist/*.c)
		root=`basename $file .c`
		fhist_files="$fhist_files fhist/${root}.o"
		clean_files="$clean_files fhist/${root}.o"
		;;

	fmerge/*.c)
		root=`basename $file .c`
		fmerge_files="$fmerge_files fmerge/${root}.o"
		clean_files="$clean_files fmerge/${root}.o"
		;;

	common/*.c)
		root=`basename $file .c`
		common_files="$common_files common/${root}.o"
		clean_files="$clean_files common/${root}.o"
		;;

	man1/*.1)
		root=`basename $file .1`
		clean_files="$clean_files man1/${root}.h"
		man1_files="$man1_files \$(mandir)/$file"
		;;

	man1/*.so)
		root=`basename $file .so`
		clean_files="$clean_files man1/${root}.h"
		;;

	test/*/*)
		root=`basename $file .sh`
		test_files="$test_files $root"
		;;

	txt2c/*.c)
		root=`basename $file .c`
		txt2c_files="$txt2c_files txt2c/${root}.o"
		clean_files="$clean_files txt2c/${root}.o"
		;;

	*)
		;;
	esac
done

#
# The variable parts
#
echo
echo "CleanFiles =" $clean_files
echo
echo "CommonFiles =" $common_files
echo
echo "FcompFiles =" $fcomp_files
echo
echo "FhistFiles =" $fhist_files
echo
echo "FmergeFiles =" $fmerge_files
echo
echo "TestFiles =" $test_files
echo
echo "Man1Files =" $man1_files
echo
echo "Txt2cFiles =" $txt2c_files

#
# emit the constant part
#
cat << 'fubar'

clean-obj:
	rm -f $(CleanFiles)

clean: clean-obj
	rm -f bin/fcomp bin/fhist bin/fmerge

distclean: clean
	rm -f config.status Makefile common/config.h

common/lib.a: $(CommonFiles)
	rm -f common/lib.a
	ar cq common/lib.a $(CommonFiles)
	$(RANLIB) common/lib.a

.bin:
	mkdir bin
	@touch .bin
	@sleep 1

bin/fcomp: $(FcompFiles) common/lib.a .bin
	$(CC) -o bin/fcomp $(FcompFiles) common/lib.a $(LIBS)
	chmod 755 bin/fcomp

$(bindir)/fcomp: bin/fcomp
	$(INSTALL_PROGRAM) bin/fcomp $(bindir)/fcomp

bin/fhist: $(FhistFiles) common/lib.a .bin
	$(CC) -o bin/fhist $(FhistFiles) common/lib.a $(LIBS)
	chmod 755 bin/fhist

$(bindir)/fhist: bin/fhist
	$(INSTALL_PROGRAM) bin/fhist $(bindir)/fhist

bin/fmerge: $(FmergeFiles) common/lib.a .bin
	$(CC) -o bin/fmerge $(FmergeFiles) common/lib.a $(LIBS)
	chmod 755 bin/fmerge

$(bindir)/fmerge: bin/fmerge
	$(INSTALL_PROGRAM) bin/fmerge $(bindir)/fmerge

bin/txt2c: $(Txt2cFiles) .bin
	$(CC) -o bin/txt2c $(Txt2cFiles) $(LIBS)
	@sleep 1

sure: $(TestFiles)
	@echo Passed All Tests

install-bin: $(bindir)/fcomp $(bindir)/fhist $(bindir)/fmerge

install-man: $(Man1Files)

install: install-bin install-man
	@echo Installation Complete
fubar

exit 0
