/*
 *	fhist - file history and comparison tools
 *	Copyright (C) 1991, 1992, 1993, 1994 Peter Miller.
 *	All rights reserved.
 *
 *	Derived from a work
 *	Copyright (C) 1990 David I. Bell.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * MANIFEST: Unix-specific routines to implement special actions.
 */

#include <signal.h>

#include <breaks.h>

#if defined(sun) || defined(__sun__)
#define sighold(n)
#define sigrelse(n)
#endif


static int breakflag;		/* TRUE if breaks are disabled */


/*
 * Routine to disable signals during a critical section of code.
 * The signals are held until the critical section is done.
 */

void
breaksoff()
{
	if (breakflag)
		return;
	breakflag = 1;
	sighold(SIGHUP);
	sighold(SIGINT);
	sighold(SIGQUIT);
	sighold(SIGTERM);
}


/*
 * Routine to reenable signals when critical code is complete.
 */

void
breakson()
{
	if (!breakflag)
		return;
	sigrelse(SIGHUP);
	sigrelse(SIGINT);
	sigrelse(SIGQUIT);
	sigrelse(SIGTERM);
	breakflag = 0;
}
